pub struct PerformanceMetrics {
pub database_response_time_ms: Option<f64>,
pub average_queue_depth: f64,
pub jobs_per_second: f64,
pub memory_usage_mb: Option<f64>,
pub cpu_usage_percent: Option<f64>,
pub active_workers: Option<u32>,
pub worker_utilization: Option<f64>,
}Expand description
Performance metrics
Fields
database_response_time_ms: Option<f64>Measured time to fetch the queue statistics for this response.
average_queue_depth: f64jobs_per_second: f64memory_usage_mb: Option<f64>cpu_usage_percent: Option<f64>active_workers: Option<u32>Always null: Hammerwork has no worker registry, so worker counts are unknown.
worker_utilization: Option<f64>Always null, see active_workers.